<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2014 Stephan Langenegger
*
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

/**
 * This view helper gets the active website language
 *
 * @copyright  2014 Copyright belongs to the respective authors
 * @license    http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 * @package    Urd
 */
class Tx_Urd_ViewHelpers_Language_CurrentViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractViewHelper {
	/**
	 * @var	tslib_cObj
	 */
	protected $cObj;

	/**
	 * Initialize
	 *
	 * @return void
	 */
	public function initializeArguments() {
		$this->registerArgument("defaultLanguage", "string", "Label of the default language", true);
		$this->registerArgument("useCacheHash", "boolean", "Use typolink chash", false, true);
		$this->registerArgument("field", "string", "The name of a single field", false, "");
	}

	/**
	 * Add a new variable
	 *
	 * @return 	array
	 */
	public function render() {
		// Create cObj instance
		$this->cObj = new \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer();

		// Get current page id
		$iPageID								= $GLOBALS['TSFE']->id;

		// Get active language uid
		$iActiveLanguage						= $GLOBALS['TSFE']->sys_language_uid;

		// Get the active language
		$aActiveLanguage						= $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
			"uid, title",
			"sys_language",
			"uid = " . $iActiveLanguage . " " . $this->cObj->enableFields("sys_language")
		);

		if(empty($aActiveLanguage)) {
			$aActiveLanguage					= array(
				"uid"								=> 0,
				"title"								=> $this->arguments["defaultLanguage"]
			);
		} else {
			$aActiveLanguage					= $aActiveLanguage[0];
		}

		// Create url
		$aUrlParams 							= \TYPO3\CMS\Core\Utility\GeneralUtility::_GET();
		$aUrlParams["L"] 						= $aActiveLanguage["uid"];

		unset($aUrlParams["id"]);
		unset($aUrlParams["cHash"]);

		$sTypolink								= $this->cObj->typoLink("",
			array(
				'parameter' 						=> $iPageID,
				'returnLast' 						=> 'url',
				'additionalParams' 					=> '&' . http_build_query($aUrlParams),
				'useCacheHash'						=> $this->arguments["useCacheHash"]
			)
		);

		$aActiveLanguage["url"]					= $sTypolink;

		// Return single field or complete array
		if(trim($this->arguments["field"]) != "") {
			return  $aActiveLanguage[$this->arguments["field"]];
		} else {
			return  $aActiveLanguage;
		}
	}
}

?>