<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2014 Stephan Langenegger
*
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

/**
 * This view helper gets all active website languages
 *
 * @copyright  2014 Copyright belongs to the respective authors
 * @license    http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 * @package    Urd
 */
class Tx_Urd_ViewHelpers_Language_ListViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractViewHelper {
	/**
	 * @var	tslib_cObj
	 */
	protected $cObj;

	/**
	 * Initialize
	 *
	 * @return void
	 */
	public function initializeArguments() {
		$this->registerArgument("defaultLanguage", "string", "Label of the default language", true);
		$this->registerArgument("showOnlyTranslated", "boolean", "Show only translated language", false, true);
		$this->registerArgument("showActive", "boolean", "Show the active language", false, true);
		$this->registerArgument("sorting", "string", "Sorted list of language ids", false, null);
		$this->registerArgument("useCacheHash", "boolean", "Use typolink chash", false, true);
	}

	/**
	 * Add a new variable
	 *
	 * @return 	array
	 */
	public function render() {
		// Create cObj instance
		$this->cObj = new \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer();

		// Set default language
		$aLanguagesList 						= array(array());

		$aLanguagesList[0]["uid"]				= 0;
		$aLanguagesList[0]["title"]				= $this->arguments["defaultLanguage"];

		// Get current page id
		$iPageID								= $GLOBALS['TSFE']->id;

		// Get active language uid
		$iActiveLanguage						= $GLOBALS['TSFE']->sys_language_uid;

		// Get page overlays
		$aPageLangOverlays 						= $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
			"DISTINCT sys_language_uid",
			"pages_language_overlay",
			"pid=" . $iPageID . " " . $GLOBALS['TSFE']->sys_page->enableFields("pages_language_overlay")
		);

		$aPageLanguages							= array(-1);

		foreach($aPageLangOverlays as $aPageLang) {
			$aPageLanguages[]					= $aPageLang["sys_language_uid"];
		}

		// Get all active system languages
		$aSysLanguages							= $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
			"uid, title",
			"sys_language",
			"uid IN (".implode(',', $aPageLanguages).")" . $this->cObj->enableFields("sys_language")
		);

		// Get only translated languages
		foreach($aSysLanguages as $aLanguage) {
			if(!$this->arguments["showOnlyTranslated"] || !empty($aPageLangOverlays)) {
				$aLanguagesList[]				= $aLanguage;
			}
		}

		// Get links
		foreach($aLanguagesList as $key => $aLanguage) {
			$aUrlParams 						= \TYPO3\CMS\Core\Utility\GeneralUtility::_GET();
			$aUrlParams["L"] 					= $aLanguage["uid"];

			unset($aUrlParams["id"]);
			unset($aUrlParams["cHash"]);

			$sTypolink							= $this->cObj->typoLink("",
				array(
					'parameter' 		=> $iPageID,
					'returnLast' 		=> 'url',
					'additionalParams' 	=> '&' . http_build_query($aUrlParams),
					'useCacheHash'		=> $this->arguments["useCacheHash"]
				)
			);

			$aLanguagesList[$key]["url"]		= $sTypolink;
			$aLanguagesList[$key]["active"]		= $aLanguage["uid"] == $iActiveLanguage;

			if($aLanguagesList[$key]["active"] && !$this->arguments["showActive"]) {
				unset($aLanguagesList[$key]);
			}
		}

		/*if(is_null($this->arguments["sorting"])) {
			usort($aLanguagesList, function($a, $b){
				return strcmp($a["title"], $b["title"]);
			});
		} else {

		}*/

		return $aLanguagesList;
	}
}

?>