<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2014 Stephan Langenegger
*
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

/**
 * This view helper gets a breadcrumb as array
 *
 * @copyright  2014 Copyright belongs to the respective authors
 * @license    http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 * @package    Urd
 */
class Tx_Urd_ViewHelpers_Menu_BreadcrumbViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractViewHelper {
	/**
	 * Initialize
	 *
	 * @return void
	 */
	public function initializeArguments() {
		$this->registerArgument("pageUid", "string", "The pageids witch sould be used as the entrylevel", false, null);
		$this->registerArgument("showHidden", "boolean", "Show hidden pages", false, false);
		$this->registerArgument("startLevel", "integer", "The start level", false, 1);
		$this->registerArgument("showLast", "boolean", "Show the current active page in the breadcrumb", false, true);
		$this->registerArgument("hideDoktypes", "string", "Doktypes to hide", false, "199,254,255");
		$this->registerArgument("reverse", "boolean", "Return the breadcrumb in reverse order", false, false);
	}

	/**
	 * Gets the breadcrumb array
	 *
	 * @return array Pages array
	 */
	public function render() {
		// Set pageUid to the current TSFE id
		if(is_null($this->arguments["pageUid"])) {
			$this->arguments["pageUid"]		= $GLOBALS["TSFE"]->id;
		}

		// Create instances
		$oPageSelect						= new \TYPO3\CMS\Frontend\Page\PageRepository();
		$oContentObject 					= new \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer();

		// Set language
		$oPageSelect->sys_language_uid		= $GLOBALS["TSFE"]->sys_language_uid;

		// Get rootline
		$aRootline							= array_reverse($oPageSelect->getRootLine($this->arguments["pageUid"]));

		$iLevel								= 1;
		$aBreadcrumb						= array();

		// Remove last (active) page
		if(!$this->arguments["showLast"]) {
			unset($aRootline[count($aRootline) - 1]);
		}

		// Create breadcrumb
		foreach($aRootline as $aPage) {
			$aCurrentPage					= $oPageSelect->getPage($aPage["uid"]);

			if(array_search($aCurrentPage["doktype"], explode(",", $this->arguments["hideDoktypes"])) === false && !empty($aCurrentPage) && ($this->arguments["showHidden"] || $aCurrentPage["nav_hide"] == 0) && $iLevel >= $this->arguments["startLevel"]) {
				$aPageDetails 				= array(
					"uid"						=> $aCurrentPage["uid"],
					"title"						=> (trim($aCurrentPage["nav_title"]) != "") ? $aCurrentPage["nav_title"] : $aCurrentPage["title"],
					"url"						=> $oContentObject->getTypoLink_URL($aPage["uid"]),
					"active"					=> $aPage["uid"] == $this->arguments["pageUid"],
					"info"						=> $aCurrentPage
				);

				$aBreadcrumb[]				= $aPageDetails;
			}

			$iLevel++;
		}

		// Reverse array
		if($this->arguments["reverse"]) {
			return array_reverse($aBreadcrumb);
		} else {
			return $aBreadcrumb;
		}
	}
}
?>