<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2014 Stephan Langenegger
*
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

/**
 * This view helper gets a page tree as array
 *
 * @copyright  2014 Copyright belongs to the respective authors
 * @license    http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 * @package    Urd
 */
class Tx_Urd_ViewHelpers_Menu_TreeViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractViewHelper {
	/**
	 * @var t3lib_pageSelect
	 */
	protected $pageSelect;

	/**
	 * @var $this->contentObject
	 */
	protected $contentObject;

	/**
	 * Initialize
	 *
	 * @return void
	 */
	public function initializeArguments() {
		$this->registerArgument("pageUid", "string", "The pageids witch sould be used as the entrylevel", false, null);
		$this->registerArgument("startLevel", "integer", "The start level", false, null);
		$this->registerArgument("maxLevels", "integer", "The maximal amount of levels", false, 1);
		$this->registerArgument("showHidden", "boolean", "Show hidden pages", false, false);
		$this->registerArgument("hideDoktypes", "string", "Doktypes to hide", false, "199,254,255");
	}

	/**
	 * Get recursive page tree
	 *
	 * @return array
	 */
	protected function getPageTree($pageUid, $startLevel, $maxLevels, $showHidden, $hideDoktypes, $level = 1) {
		$aPages 							= array();
		$aPageUids							= explode(",", $pageUid);

		// Set language
		$this->pageSelect->sys_language_uid	= $GLOBALS["TSFE"]->sys_language_uid;

		// Create page tree
		if($level <= $maxLevels) {
			foreach($aPageUids as $iPageUid) {
				$aCurrentPage				= $this->pageSelect->getPage($iPageUid);

				if(array_search($aCurrentPage["doktype"], explode(",", $hideDoktypes)) === false) {
					$aAllSubPages				= explode(",", $this->contentObject->getTreeList(-$iPageUid, 100, 0, false, "", "AND deleted = 0"));
					$lSubPages					= $this->contentObject->getTreeList($iPageUid, 1, 0, false, "", "AND deleted = 0 AND hidden = 0" . ((!$showHidden) ? " AND nav_hide <> 1" : ""));
					$lSubPages					= trim($lSubPages, ",");

					$sMountPoint				= ($aCurrentPage["doktype"] == 7) ? $aCurrentPage["mount_pid"]."-".$iPageUid : "";

					$aPageDetails 				= array(
						"uid"						=> $aCurrentPage["uid"],
						"title"						=> (trim($aCurrentPage["nav_title"]) != "") ? $aCurrentPage["nav_title"] : $aCurrentPage["title"],
						"active"					=> array_search($GLOBALS["TSFE"]->id, $aAllSubPages) !== false,
						"level"						=> $level,
						"url"						=> $this->contentObject->getTypoLink_URL($aCurrentPage["uid"]),
						"subPages"					=> array(),
						"info"						=> $aCurrentPage,
						"doktype"					=> $aCurrentPage["doktype"]
					);

					if($lSubPages != "") {
						$aPageDetails["subPages"]	= $this->getPageTree($lSubPages, $startLevel, $maxLevels, $showHidden, $hideDoktypes, $level + 1);
					}

					if($GLOBALS["TSFE"]->sys_language_uid != 0) {
						$iLanguage 					= $GLOBALS['TYPO3_DB']->exec_SELECTcountRows(
							"sys_language_uid",
							"pages_language_overlay",
							"pid=" . $aCurrentPage["uid"] . " AND sys_language_uid = " . $GLOBALS['TSFE']->sys_language_uid . " " . $GLOBALS['TSFE']->sys_page->enableFields("pages_language_overlay")
						);

						if($iLanguage > 0) {
							$aPages[] 				= $aPageDetails;
						}
					} else {
						$aPages[] 					= $aPageDetails;
					}
				}
			}
		}

		return $aPages;
	}

	/**
	 * Gets an page tree array
	 *
	 * @return array Pages array
	 */
	public function render() {
		// Create instances
		$this->pageSelect 							= new \TYPO3\CMS\Frontend\Page\PageRepository();
		$this->contentObject 						= new \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer();

		// Dont show disabled and hidden pages
		$this->pageSelect->init(false);

		// Get rootline
		$aRootLine									= $this->pageSelect->getRootLine($GLOBALS["TSFE"]->id);

		// Get page ids for a specific level
		if(is_null($this->arguments["pageUid"]) && !is_null($this->arguments["startLevel"])) {
			$iParentLevelID							= $aRootLine[$this->arguments["startLevel"] - 2]["uid"];

			if($this->arguments["startLevel"] - 2 < 0) {
				$this->arguments["pageUid"]			= $aRootLine[0]["uid"];
			} elseif($this->arguments["startLevel"] - 2 >= count($aRootLine)) {
				$this->arguments["pageUid"]			= $this->contentObject->getTreeList($GLOBALS['TSFE']->id, $this->arguments["startLevel"] - count($aRootLine), ($this->arguments["startLevel"] - count($aRootLine) - 1), false, "", "AND deleted = 0 AND hidden = 0" . ((!$this->arguments["showHidden"]) ? " AND nav_hide <> 1" : ""));;
				$this->arguments["pageUid"]			= trim($this->arguments["pageUid"], ",");
			} else {
				$this->arguments["pageUid"]			= $this->contentObject->getTreeList($iParentLevelID, 1, 0, false, "", "AND deleted = 0 AND hidden = 0" . ((!$this->arguments["showHidden"]) ? " AND nav_hide <> 1" : ""));
				$this->arguments["pageUid"]			= trim($this->arguments["pageUid"], ",");
			}
		} elseif(!is_null($this->arguments["pageUid"]) && !is_null($this->arguments["startLevel"])) {
			if($this->arguments["startLevel"] > 1) {
				$lPages								= "";

				foreach(explode(",", $this->arguments["pageUid"]) as $pid) {
					$lPages 						.= $this->contentObject->getTreeList($pid, $this->arguments["startLevel"] - 1, $this->arguments["startLevel"] - 2, false, "", "AND deleted = 0 AND hidden = 0" . ((!$this->arguments["showHidden"]) ? " AND nav_hide <> 1" : ""));
				}

				$this->arguments["pageUid"]			= trim($lPages, ",");
			}
		}

		if(is_null($this->arguments["pageUid"]) || $this->arguments["pageUid"] == "") {
			return array();
		} else {
			return $this->getPageTree($this->arguments["pageUid"], $this->arguments["startLevel"], $this->arguments["maxLevels"], $this->arguments["showHidden"], $this->arguments["hideDoktypes"]);
		}
	}
}
?>