<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2014 Stephan Langenegger
*
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

/**
 * This view helper handles parameter strings using typolink function of TYPO3.
 * It creates the whole <a>-Tag.
 *
 * @copyright  2014 Copyright belongs to the respective authors
 * @license    http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */
class Tx_Urd_ViewHelpers_Typolink_LinkViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractViewHelper {
	/**
	 * @var string
	 */
	protected $tagName = "a";

	/**
	 * Arguments initialization
	 *
	 * @return void
	 */
	public function initializeArguments() {
		$this->registerArgument("link", "string", "Parameter string, which can be handled by typolink functionality", true);
		$this->registerArgument("attributes", "array", "Additional attributes", false, array());
		$this->registerArgument("attributesPageLink", "array", "Additional attributes (only for page links)", false, array());
		$this->registerArgument("attributesEmailLink", "array", "Additional attributes (only for email links)", false, array());
		$this->registerArgument("attributesFileLink", "array", "Additional attributes (only for file links)", false, array());
		$this->registerArgument("attributesExternalLink", "array", "Additional attributes (only for external links)", false, array());
		$this->registerArgument("noLinkTag", "string", "No link tag", false, "a");
	}

	/**
	 * Create a typolink.
	 *
	 * @return string Rendered HTML <a>-tag
	 */
	public function render() {
		$subject = $this->renderChildren();

		$cObj 		= new \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer();
		$aParams	= explode(" ", $this->arguments["link"]);
		$aNewParams	= array();
		$sNewLink	= "";

		$sUrl 		= $aParams[0];
		$sTarget	= isset($aParams[1]) ? $aParams[1] : "-";
		$sCss		= isset($aParams[2]) ? $aParams[2] : "-";
		$sTitle		= isset($aParams[3]) ? $aParams[3] : "-";
		$sParam		= isset($aParams[4]) ? $aParams[4] : "";

		if($sTarget != "-") {
			$aNewParams['target']	= $sTarget;
		}

		if($sCss != "-") {
			$aNewParams['class']	= $sCss;
		}

		if($sTitle != "-") {
			$aNewParams['title']	= $sTitle;
		}

		$sTypolink					= $cObj->getTypoLink_URL("$sUrl $sTarget - - $sParam");

		if(is_numeric($sUrl)) {
			$sLinkType	= "page";
		} elseif(preg_match("[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?", $sUrl) !== false) {
			$sLinkType	= "email";
		} elseif(count(explode(":", $sUrl)) == 3 && strpos($sUrl, "http") !== 0) {
			$sLinkType	= "folder";
		} elseif(count(explode(":", $sUrl)) == 2 && strpos($sUrl, "http") !== 0) {
			$sLinkType	= "file";
		} else {
			$sLinkType	= "extern";
		}

		foreach($this->arguments["attributes"] as $sParamKey => $sParamValue) {
			$aNewParams[$sParamKey] = $sParamValue;
		}

		if($sLinkType == 'page') {
			$aNewParams				= array_merge($aNewParams, $this->arguments["attributesPageLink"]);
		} else if($sLinkType == 'email') {
			$aNewParams				= array_merge($aNewParams, $this->arguments["attributesEmailLink"]);
		} else if($sLinkType == 'file') {
			$aNewParams				= array_merge($aNewParams, $this->arguments["attributesFileLink"]);
		} else if($sLinkType == 'extern') {
			$aNewParams				= array_merge($aNewParams, $this->arguments["attributesExternalLink"]);
		}

		$aNewParams['href']			= $sTypolink;

		$tagName					= "a";

		if(trim($aNewParams['href']) == '') {
			$tagName				= $this->arguments["noLinkTag"];

			unset($aNewParams['href']);
			unset($aNewParams['target']);
		}

		// Generate a attributes
		$sNewLink					= '<'.$tagName;

		foreach($aNewParams as $sParamKey => $sParamValue) {
			$sNewLink				.= ' '.$sParamKey. '="'.$sParamValue.'"';
		}

		$sNewLink					.= '>'.$subject.'</'.$tagName.'>';

		return $sNewLink;
	}
}
?>